# Generated by roxygen2: do not edit by hand

S3method(c,IBDprob)
S3method(plot,IBDprob)
S3method(summary,IBDprob)
export(calcIBD)
export(getProbs)
export(readIBDs)
export(readRABBIT)
export(writeFlapjack)
export(writeIBDs)
importFrom(Rcpp,sourceCpp)
importFrom(rlang,.data)
importFrom(stats,aggregate)
importFrom(stats,reshape)
importFrom(utils,getFromNamespace)
importFrom(utils,hasName)
importFrom(utils,head)
importFrom(utils,read.table)
importFrom(utils,tail)
importFrom(utils,unzip)
importFrom(utils,write.table)
useDynLib(statgenIBD, .registration = TRUE)
